analphipy.PhiBase
=================

.. currentmodule:: analphipy

.. autoclass:: PhiBase

   
   ..
      .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree:
   
      ~PhiBase.__init__
      ~PhiBase.asdict
      ~PhiBase.assign
      ~PhiBase.assign_min_numeric
      ~PhiBase.cut
      ~PhiBase.dphidr
      ~PhiBase.lfs
      ~PhiBase.minimize
      ~PhiBase.new_like
      ~PhiBase.phi
      ~PhiBase.to_measures
      ~PhiBase.to_nf
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree:
   
      ~PhiBase.phi_min
      ~PhiBase.r_min
      ~PhiBase.segments
   
   

   
   
   .. rubric:: Dunder Methods

   .. autosummary::
      :toctree:
   
      ~PhiBase.__repr__
   
   